feast.types package — Feast 0.3.2 documentation

# feast.types package

## Submodules

## feast.types.FeatureRowExtended_pb2 module

class `feast.types.FeatureRowExtended_pb2.` `Attempt`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  `attempts`

    Field feast.types.Attempt.attempts

  `error`

    Field feast.types.Attempt.error

class `feast.types.FeatureRowExtended_pb2.` `Error`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  `cause`

    Field feast.types.Error.cause

  `message`

    Field feast.types.Error.message

  `stack_trace`

    Field feast.types.Error.stack_trace

  `transform`

    Field feast.types.Error.transform

class `feast.types.FeatureRowExtended_pb2.` `FeatureRowExtended`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  `first_seen`

    Field feast.types.FeatureRowExtended.first_seen

  `last_attempt`

    Field feast.types.FeatureRowExtended.last_attempt

  `row`

    Field feast.types.FeatureRowExtended.row

## feast.types.FeatureRow_pb2 module

class `feast.types.FeatureRow_pb2.` `FeatureRow`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  `event_timestamp`

    Field feast.types.FeatureRow.event_timestamp

  `feature_set`

    Field feast.types.FeatureRow.feature_set

  `fields`

    Field feast.types.FeatureRow.fields

## feast.types.Feature_pb2 module

class `feast.types.Feature_pb2.` `Feature`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  `name`

    Field feast.types.Feature.name

  `value`

    Field feast.types.Feature.value

## feast.types.Field_pb2 module

class `feast.types.Field_pb2.` `Field`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  `name`

    Field feast.types.Field.name

  `value`

    Field feast.types.Field.value

## feast.types.Value_pb2 module

class `feast.types.Value_pb2.` `BoolList`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  `val`

    Field feast.types.BoolList.val

class `feast.types.Value_pb2.` `BytesList`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  `val`

    Field feast.types.BytesList.val

class `feast.types.Value_pb2.` `DoubleList`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  `val`

    Field feast.types.DoubleList.val

class `feast.types.Value_pb2.` `FloatList`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  `val`

    Field feast.types.FloatList.val

class `feast.types.Value_pb2.` `Int32List`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  `val`

    Field feast.types.Int32List.val

class `feast.types.Value_pb2.` `Int64List`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  `val`

    Field feast.types.Int64List.val

class `feast.types.Value_pb2.` `StringList`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  `val`

    Field feast.types.StringList.val

class `feast.types.Value_pb2.` `Value`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  `bool_list_val`

    Field feast.types.Value.bool_list_val

  `bool_val`

    Field feast.types.Value.bool_val

  `bytes_list_val`

    Field feast.types.Value.bytes_list_val

  `bytes_val`

    Field feast.types.Value.bytes_val

  `double_list_val`

    Field feast.types.Value.double_list_val

  `double_val`

    Field feast.types.Value.double_val

  `float_list_val`

    Field feast.types.Value.float_list_val

  `float_val`

    Field feast.types.Value.float_val

  `int32_list_val`

    Field feast.types.Value.int32_list_val

  `int32_val`

    Field feast.types.Value.int32_val

  `int64_list_val`

    Field feast.types.Value.int64_list_val

  `int64_val`

    Field feast.types.Value.int64_val

  `string_list_val`

    Field feast.types.Value.string_list_val

  `string_val`

    Field feast.types.Value.string_val

class `feast.types.Value_pb2.` `ValueType`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `BOOL` = 7
  `BOOL_LIST` = 17
  `BYTES` = 1
  `BYTES_LIST` = 11
  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  `DOUBLE` = 5
  `DOUBLE_LIST` = 15
  `Enum` = <google.protobuf.internal.enum_type_wrapper.EnumTypeWrapper object>
  `FLOAT` = 6
  `FLOAT_LIST` = 16
  `INT32` = 3
  `INT32_LIST` = 13
  `INT64` = 4
  `INT64_LIST` = 14
  `INVALID` = 0
  `STRING` = 2
  `STRING_LIST` = 12

## Module contents